@@ -392,7 +392,7 @@ class BrowserView(QMainWindow):
                  height=default_window_height,
                  resizable=True, full_screen=False, min_size=(min_window_width, min_window_height),
                  background_color="#ffffff", web_view_ready=None, cid='', enable_max=True, window_type='cef',
-                 quit_app_when_main_window_close=True, popup_validate=None):
+                 quit_app_when_main_window_close=True, popup_validate=None,extendScreen="false"):
         super(BrowserView, self).__init__()
         BrowserView.instances[uid] = self
         screen = QDesktopWidget().screenGeometry()
@@ -422,7 +422,10 @@ class BrowserView(QMainWindow):
 
         # 处理默认窗口大小
         if width != -1 and height != -1:
-            self.resize(width, height)
+            if extendScreen == "true":
+                self.resize(screen_width, screen_height)
+            else:
+                self.resize(width, height)
         else:
             self.resize(screen_width * 0.85, screen_height * 0.8)
 
@@ -444,7 +447,7 @@ class BrowserView(QMainWindow):
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.setWindowFlags(Qt.CustomizeWindowHint | Qt.WindowMinMaxButtonsHint | Qt.WindowCloseButtonHint)
         # 禁用窗口最大化
-        if not enable_max:
+        if not enable_max  and extendScreen=="false":
             self.setFixedSize(self.width(), self.height())
             self.setWindowFlags(Qt.CustomizeWindowHint | Qt.WindowMinimizeButtonHint | Qt.WindowCloseButtonHint)
 
@@ -476,7 +479,10 @@ class BrowserView(QMainWindow):
         if full_screen:
             self.emit_full_screen_signal()
 
-        self.move(QApplication.desktop().availableGeometry().center() - self.rect().center())
+        if extendScreen == "true":
+            self.move(screen_width, 0)
+        else:
+            self.move(QApplication.desktop().availableGeometry().center() - self.rect().center())
         self.activateWindow()
         self.raise_()
         if web_view_ready is not None:
@@ -613,9 +619,10 @@ class BrowserView(QMainWindow):
             param.setdefault('width', default_window_width)
             param.setdefault('height', default_window_height)
             param.setdefault('enableMax', True)
+            param.setdefault('extendScreen','false')
             open_new_window(url=param["url"], title=param["title"], payload=param["payload"],
                             maximized=param["maximized"], minimized=param["minimized"], cid=param["cid"],
-                            width=param["width"], height=param["height"], enable_max=param["enableMax"])
+                            width=param["width"], height=param["height"], enable_max=param["enableMax"],extendScreen=param["extendScreen"])
         elif isinstance(param, str):
             open_new_window(url=param)
 
@@ -1155,11 +1162,11 @@ def generate_guid(prefix='child'):
 
 
 def open_new_window(url, title=default_window_title, payload=None, maximized=False, minimized=False, cid='',
-                    width=default_window_width, height=default_window_height, enable_max=True):
+                    width=default_window_width, height=default_window_height, enable_max=True,extendScreen="false"):
     logging.debug('[Open New Window] : url={url}, cid={cid}'.format(url=url, cid=cid))
     create_browser_view(uid=generate_guid(), url=url, title=title, payload=payload, maximized=maximized,
                         minimized=minimized, cid=cid, width=width, height=height, enable_max=enable_max,
-                        inject_obj=app_inject_obj, application_version=app_version_info)
+                        inject_obj=app_inject_obj, application_version=app_version_info,extend_Screen=extendScreen)
 
 
 def create_qt_view(default_show=True, window_type='cef', url='', cid='', payload={}, popup_validate=None):
@@ -1206,15 +1213,15 @@ def create_browser_view(uid, title="", url=None, width=default_window_width, hei
                         background_color="#ffffff", web_view_ready=None, payload=None, maximized=False,
                         minimized=False, cid='', call_back=None, enable_max=True, inject_obj=app_inject_obj,
                         quit_app_when_main_window_close=True, application_version=app_version_info,
-                        popup_validate=None):
+                        popup_validate=None,extend_Screen="false"):
     browser = BrowserView(uid, title, url, width, height, resizable, full_screen, min_size,
                           background_color, web_view_ready, cid=cid, enable_max=enable_max,
                           quit_app_when_main_window_close=quit_app_when_main_window_close,
-                          popup_validate=popup_validate)
-    if maximized:
+                          popup_validate=popup_validate,extendScreen=extend_Screen)
+    if maximized  and extend_Screen=='false':
         browser.showMaximized()
 
-    if minimized:
+    if minimized  and extend_Screen=='false':
         browser.showMinimized()
 
     browser.show()
